=======
History
=======

1.0.1 (2018-08-02)
------------------

* Restrict to only supported py2neo versions with environment-based override for
  testing with later versions.

1.0.0 (2018-08-01)
------------------

* First release on PyPI.
